==> kibana-7.6.2p0.tgz: kibana/src/plugins/data/public/ui/filter_bar/filter_options.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FilterOptions = void 0;

var _eui = require("@elastic/eui");

var _react = require("@kbn/i18n/react");

var _react2 = _interopRequireWildcard(require("react"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var FilterOptionsUI =
/*#__PURE__*/
function (_Component) {
  _inherits(FilterOptionsUI, _Component);

  function FilterOptionsUI() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, FilterOptionsUI);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(FilterOptionsUI)).call.apply(_getPrototypeOf2, [this].concat(args)));

    _defineProperty(_assertThisInitialized(_this), "state", {
      isPopoverOpen: false
    });

    _defineProperty(_assertThisInitialized(_this), "togglePopover", function () {
      _this.setState(function (prevState) {
        return {
          isPopoverOpen: !prevState.isPopoverOpen
        };
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closePopover", function () {
      _this.setState({
        isPopoverOpen: false
      });
    });

    return _this;
  }

  _createClass(FilterOptionsUI, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var panelTree = {
        id: 0,
        items: [{
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.enableAllFiltersButtonLabel',
            defaultMessage: 'Enable all'
          }),
          icon: 'eye',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onEnableAll();
          },
          'data-test-subj': 'enableAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.disableAllFiltersButtonLabel',
            defaultMessage: 'Disable all'
          }),
          icon: 'eyeClosed',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onDisableAll();
          },
          'data-test-subj': 'disableAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.pinAllFiltersButtonLabel',
            defaultMessage: 'Pin all'
          }),
          icon: 'pin',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onPinAll();
          },
          'data-test-subj': 'pinAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.unpinAllFiltersButtonLabel',
            defaultMessage: 'Unpin all'
          }),
          icon: 'pin',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onUnpinAll();
          },
          'data-test-subj': 'unpinAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.invertNegatedFiltersButtonLabel',
            defaultMessage: 'Invert inclusion'
          }),
          icon: 'invert',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onToggleAllNegated();
          },
          'data-test-subj': 'invertInclusionAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.invertDisabledFiltersButtonLabel',
            defaultMessage: 'Invert enabled/disabled'
          }),
          icon: 'eye',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onToggleAllDisabled();
          },
          'data-test-subj': 'invertEnableDisableAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.deleteAllFiltersButtonLabel',
            defaultMessage: 'Remove all'
          }),
          icon: 'trash',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onRemoveAll();
          },
          'data-test-subj': 'removeAllFilters'
        }]
      };
      return _react2.default.createElement(_eui.EuiPopover, {
        id: "popoverForAllFilters",
        className: "globalFilterGroup__allFiltersPopover",
        isOpen: this.state.isPopoverOpen,
        closePopover: this.closePopover,
        button: _react2.default.createElement(_eui.EuiButtonIcon, {
          onClick: this.togglePopover,
          iconType: "filter",
          "aria-label": this.props.intl.formatMessage({
            id: 'data.filter.options.changeAllFiltersButtonLabel',
            defaultMessage: 'Change all filters'
          }),
          title: this.props.intl.formatMessage({
            id: 'data.filter.options.changeAllFiltersButtonLabel',
            defaultMessage: 'Change all filters'
          }),
          "data-test-subj": "showFilterActions"
        }),
        anchorPosition: "rightUp",
        panelPaddingSize: "none",
        withTitle: true
      }, _react2.default.createElement(_eui.EuiPopoverTitle, null, _react2.default.createElement(_react.FormattedMessage, {
        id: "data.filter.searchBar.changeAllFiltersTitle",
        defaultMessage: "Change all filters"
      })), _react2.default.createElement(_eui.EuiContextMenu, {
        initialPanelId: 0,
        panels: [panelTree]
      }));
    }
  }]);

  return FilterOptionsUI;
}(_react2.Component);

var FilterOptions = (0, _react.injectI18n)(FilterOptionsUI);
exports.FilterOptions = FilterOptions;

==> kibana-7.9.1.tgz: kibana/src/plugins/data/public/ui/filter_bar/filter_options.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { EuiButtonIcon, EuiContextMenu, EuiPopover, EuiPopoverTitle } from '@elastic/eui';
import { FormattedMessage, injectI18n } from '@kbn/i18n/react';
import { Component } from 'react';
import React from 'react';

var FilterOptionsUI = /*#__PURE__*/function (_Component) {
  _inherits(FilterOptionsUI, _Component);

  var _super = _createSuper(FilterOptionsUI);

  function FilterOptionsUI() {
    var _this;

    _classCallCheck(this, FilterOptionsUI);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    _defineProperty(_assertThisInitialized(_this), "state", {
      isPopoverOpen: false
    });

    _defineProperty(_assertThisInitialized(_this), "togglePopover", function () {
      _this.setState(function (prevState) {
        return {
          isPopoverOpen: !prevState.isPopoverOpen
        };
      });
    });

    _defineProperty(_assertThisInitialized(_this), "closePopover", function () {
      _this.setState({
        isPopoverOpen: false
      });
    });

    return _this;
  }

  _createClass(FilterOptionsUI, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var panelTree = {
        id: 0,
        items: [{
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.enableAllFiltersButtonLabel',
            defaultMessage: 'Enable all'
          }),
          icon: 'eye',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onEnableAll();
          },
          'data-test-subj': 'enableAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.disableAllFiltersButtonLabel',
            defaultMessage: 'Disable all'
          }),
          icon: 'eyeClosed',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onDisableAll();
          },
          'data-test-subj': 'disableAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.pinAllFiltersButtonLabel',
            defaultMessage: 'Pin all'
          }),
          icon: 'pin',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onPinAll();
          },
          'data-test-subj': 'pinAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.unpinAllFiltersButtonLabel',
            defaultMessage: 'Unpin all'
          }),
          icon: 'pin',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onUnpinAll();
          },
          'data-test-subj': 'unpinAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.invertNegatedFiltersButtonLabel',
            defaultMessage: 'Invert inclusion'
          }),
          icon: 'invert',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onToggleAllNegated();
          },
          'data-test-subj': 'invertInclusionAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.invertDisabledFiltersButtonLabel',
            defaultMessage: 'Invert enabled/disabled'
          }),
          icon: 'eye',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onToggleAllDisabled();
          },
          'data-test-subj': 'invertEnableDisableAllFilters'
        }, {
          name: this.props.intl.formatMessage({
            id: 'data.filter.options.deleteAllFiltersButtonLabel',
            defaultMessage: 'Remove all'
          }),
          icon: 'trash',
          onClick: function onClick() {
            _this2.closePopover();

            _this2.props.onRemoveAll();
          },
          'data-test-subj': 'removeAllFilters'
        }]
      };
      return /*#__PURE__*/React.createElement(EuiPopover, {
        id: "popoverForAllFilters",
        className: "globalFilterGroup__allFiltersPopover",
        isOpen: this.state.isPopoverOpen,
        closePopover: this.closePopover,
        button: /*#__PURE__*/React.createElement(EuiButtonIcon, {
          onClick: this.togglePopover,
          iconType: "filter",
          "aria-label": this.props.intl.formatMessage({
            id: 'data.filter.options.changeAllFiltersButtonLabel',
            defaultMessage: 'Change all filters'
          }),
          title: this.props.intl.formatMessage({
            id: 'data.filter.options.changeAllFiltersButtonLabel',
            defaultMessage: 'Change all filters'
          }),
          "data-test-subj": "showFilterActions"
        }),
        anchorPosition: "rightUp",
        panelPaddingSize: "none",
        withTitle: true,
        repositionOnScroll: true
      }, /*#__PURE__*/React.createElement(EuiPopoverTitle, null, /*#__PURE__*/React.createElement(FormattedMessage, {
        id: "data.filter.searchBar.changeAllFiltersTitle",
        defaultMessage: "Change all filters"
      })), /*#__PURE__*/React.createElement(EuiContextMenu, {
        initialPanelId: 0,
        panels: [panelTree]
      }));
    }
  }]);

  return FilterOptionsUI;
}(Component);

export var FilterOptions = injectI18n(FilterOptionsUI);
